aboutsummaryrefslogtreecommitdiff
path: root/src/index.js
diff options
context:
space:
mode:
Diffstat (limited to 'src/index.js')
-rw-r--r--src/index.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/index.js b/src/index.js
index ba08056..b654f84 100644
--- a/src/index.js
+++ b/src/index.js
@@ -35,8 +35,8 @@ function start() {
},
});
- // when --debug is added it'll open the dev tools
- if (cli.hasParam("debug")) {win.openDevTools()}
+ // when --devtools is added it'll open the dev tools
+ if (cli.hasParam("devtools")) {win.openDevTools()}
// general setup
win.removeMenu();